import { world, ItemStack, GameMode } from "@minecraft/server";

export function Durability(player, itemUsed) {
    if (!itemUsed || player.matches({ gameMode: GameMode.creative })) return;
    const playerEquippableComp = player.getComponent("equippable");
    if (!playerEquippableComp) return;
    const itemEnchantmentComp = itemUsed.getComponent("minecraft:enchantable");
    const unbreakingLevel = itemEnchantmentComp?.getEnchantment("unbreaking")?.level ?? 0;
    const breakChance = 100 / (unbreakingLevel + 1);
    const randomizeChance = Math.random() * 100;
    if (breakChance < randomizeChance) return;
    const itemUsedDurabilityComp = itemUsed.getComponent("durability");
    if (!itemUsedDurabilityComp) return;
    let durabilityModifier = 0;
    if (itemUsed.hasTag('minecraft:is_sword')) {
        durabilityModifier = 2;
    } else {
        durabilityModifier = 1;
    }
    itemUsedDurabilityComp.damage += durabilityModifier;
    const maxDurability = itemUsedDurabilityComp.maxDurability
    const currentDamage = itemUsedDurabilityComp.damage
    if (currentDamage >= maxDurability) {
        player.playSound('random.break', { pitch: 1, location: player.location, volume: 1 })
        playerEquippableComp.setEquipment("Mainhand", new ItemStack('minecraft:air', 1));
    }
    else if (currentDamage < maxDurability) {
        playerEquippableComp.setEquipment("Mainhand", itemUsed);
    }

}

world.beforeEvents.worldInitialize.subscribe(eventData => {
    eventData.itemComponentRegistry.registerCustomComponent('emd:durability', {
        onMineBlock: ({ source, itemStack }) => {
            Durability(source, itemStack)
        }
    })
})